@@ -32,9 +32,15 @@ typedef struct ICC {
   int   psize;
 } ICC;
 
-ICC *icc_state_new (char *data, int length, int tags);
+ICC *
+icc_state_new (char *data, 
+               int   length, 
+               int   tags);
 
-ICC *icc_state_new (char *data, int length, int tags)
+ICC *
+icc_state_new (char *data, 
+               int   length, 
+               int   tags)
 {
   ICC *ret = babl_calloc (sizeof (ICC), 1);
   ret->data = data;
@@ -64,21 +70,29 @@ typedef struct {
 #define icc_write(type, offset, value)  write_##type(state,offset,value)
 #define icc_read(type, offset)          read_##type(state,offset)
 
-static void write_u8 (ICC *state, int offset, uint8_t value)
+static void 
+write_u8 (ICC    *state, 
+          int     offset, 
+          uint8_t value)
 {
   if (offset < 0 || offset >= state->length)
     return;
   *(uint8_t*) (&state->data[offset]) = value;
 }
 
-static void write_s8 (ICC *state, int offset, int8_t value)
+static void 
+write_s8 (ICC   *state, 
+          int    offset, 
+          int8_t value)
 {
   if (offset < 0 || offset >= state->length)
     return;
   *(int8_t*) (&state->data[offset]) = value;
 }
 
-static int read_u8 (ICC *state, int offset)
+static int 
+read_u8 (ICC *state, 
+         int  offset)
 {
 /* all reading functions take both the char *pointer and the length of the
  * buffer, and all reads thus gets protected by this condition.
@@ -89,7 +103,9 @@ static int read_u8 (ICC *state, int offset)
   return *(uint8_t*) (&state->data[offset]);
 }
 
-static int read_s8 (ICC *state, int offset)
+static int 
+read_s8 (ICC *state, 
+         int  offset)
 {
   if (offset < 0 || offset > state->length)
     return 0;
@@ -97,57 +113,78 @@ static int read_s8 (ICC *state, int offset)
   return *(int8_t*) (&state->data[offset]);
 }
 
-static void write_s16 (ICC *state, int offset, int16_t value)
+static void 
+write_s16 (ICC    *state, 
+           int     offset, 
+           int16_t value)
 {
   write_s8 (state, offset + 0, value >> 8);
   write_u8 (state, offset + 1, value & 0xff);
 }
 
-static int16_t read_s16 (ICC *state, int offset)
+static int16_t 
+read_s16 (ICC *state, 
+          int  offset)
 {
   return icc_read (u8, offset + 1) +
          (read_s8 (state, offset + 0) << 8); //XXX: transform to icc_read macro
 }
 
-static uint16_t read_u16 (ICC *state, int offset)
+static 
+uint16_t read_u16 (ICC *state, 
+                   int  offset)
 {
   return icc_read (u8, offset + 1) +
          (icc_read (u8, offset + 0) << 8);
 }
 
-static void write_u16 (ICC *state, int offset, uint16_t value)
+static void 
+write_u16 (ICC     *state, 
+           int      offset, 
+           uint16_t value)
 {
   write_u8 (state, offset + 0, value >> 8);
   write_u8 (state, offset + 1, value & 0xff);
 }
 
-static u8f8_t read_u8f8_ (ICC *state, int offset)
+static u8f8_t 
+read_u8f8_ (ICC *state, 
+            int  offset)
 {
   u8f8_t ret ={icc_read (u8, offset),
                icc_read (u8, offset + 1)};
   return ret;
 }
 
-static s15f16_t read_s15f16_ (ICC *state, int offset)
+static s15f16_t 
+read_s15f16_ (ICC *state, 
+              int  offset)
 {
   s15f16_t ret ={icc_read (s16, offset),
                  icc_read (u16, offset + 2)};
   return ret;
 }
 
-static void write_u8f8_ (ICC *state, int offset, u8f8_t val)
+static void 
+write_u8f8_ (ICC   *state, 
+             int    offset, 
+             u8f8_t val)
 {
   icc_write (u8, offset,     val.integer),
   icc_write (u8, offset + 1, val.fraction);
 }
 
-static void write_s15f16_ (ICC *state, int offset, s15f16_t val)
+static void 
+write_s15f16_ (ICC     *state, 
+               int      offset, 
+               s15f16_t val)
 {
   icc_write (s16, offset, val.integer),
   icc_write (u16, offset + 2, val.fraction);
 }
 
-static s15f16_t d_to_s15f16 (double value)
+static s15f16_t 
+d_to_s15f16 (double value)
 {
   s15f16_t ret;
   ret.integer = floor (value);
@@ -155,7 +192,8 @@ static s15f16_t d_to_s15f16 (double value)
   return ret;
 }
 
-static u8f8_t d_to_u8f8 (double value)
+static u8f8_t 
+d_to_u8f8 (double value)
 {
   u8f8_t ret;
   ret.integer = floor (value);
@@ -163,39 +201,52 @@ static u8f8_t d_to_u8f8 (double value)
   return ret;
 }
 
-static double s15f16_to_d (s15f16_t fix)
+static double 
+s15f16_to_d (s15f16_t fix)
 {
   return fix.integer + fix.fraction / 65536.0;
 }
 
-static double u8f8_to_d (u8f8_t fix)
+static double 
+u8f8_to_d (u8f8_t fix)
 {
   return fix.integer + fix.fraction / 256.0;
 }
 
-static void write_s15f16 (ICC *state, int offset, double value)
+static void 
+write_s15f16 (ICC   *state,
+              int    offset,
+              double value)
 {
    write_s15f16_ (state, offset, d_to_s15f16 (value));
 }
 
-static void write_u8f8 (ICC *state, int offset, double value)
+static void 
+write_u8f8 (ICC   *state,
+            int    offset,
+            double value)
 {
   write_u8f8_ (state, offset, d_to_u8f8 (value));
 }
 
 
-static double read_s15f16 (ICC *state, int offset)
+static double 
+read_s15f16 (ICC *state, 
+             int  offset)
 {
   return s15f16_to_d (read_s15f16_ (state, offset));
 }
 
-static double read_u8f8 (ICC *state, int offset)
+static double 
+read_u8f8 (ICC *state, 
+           int  offset)
 {
   return u8f8_to_d (read_u8f8_ (state, offset));
 }
 
 #if 0
-static inline void print_u8f8 (u8f8_t fix)
+static inline void 
+print_u8f8 (u8f8_t fix)
 {
   int i;
   uint32_t foo;
@@ -209,7 +260,8 @@ static inline void print_u8f8 (u8f8_t fix)
   }
 }
 
-static inline void print_s15f16 (s15f16_t fix)
+static inline void 
+print_s15f16 (s15f16_t fix)
 {
   int i;
   uint32_t foo;
@@ -240,7 +292,10 @@ static inline void print_s15f16 (s15f16_t fix)
 }
 #endif
 
-static void write_u32 (ICC *state, int offset, uint32_t value)
+static void 
+write_u32 (ICC     *state, 
+           int      offset, 
+           uint32_t value)
 {
   int i;
   for (i = 0; i < 4; i ++)
@@ -252,7 +307,9 @@ static void write_u32 (ICC *state, int offset, uint32_t value)
   }
 }
 
-static uint32_t read_u32 (ICC *state, int offset)
+static uint32_t 
+read_u32 (ICC *state, 
+          int  offset)
 {
   return icc_read (u8, offset + 3) +
          (icc_read (u8, offset + 2) << 8) +
@@ -260,7 +317,9 @@ static uint32_t read_u32 (ICC *state, int offset)
          (icc_read (u8, offset + 0) << 24);
 }
 
-static sign_t read_sign (ICC *state, int offset)
+static sign_t 
+read_sign (ICC *state, 
+           int  offset)
 {
   sign_t ret;
   ret.str[0]=icc_read (u8, offset);
@@ -271,7 +330,10 @@ static sign_t read_sign (ICC *state, int offset)
   return ret;
 }
 
-static void write_sign (ICC *state, int offset, const char *sign)
+static void 
+write_sign (ICC        *state, 
+            int         offset, 
+            const char *sign)
 {
   int i;
   for (i = 0; i < 4; i ++)
@@ -280,8 +342,11 @@ static void write_sign (ICC *state, int offset, const char *sign)
 
 /* looks up offset and length for a specific icc tag
  */
-static int icc_tag (ICC *state,
-                    const char *tag, int *offset, int *el_length)
+static int 
+icc_tag (ICC        *state,
+         const char *tag, 
+         int        *offset, 
+         int        *el_length)
 {
   int tag_count = icc_read (u32, TAG_COUNT_OFF);
   int t;
@@ -301,8 +366,10 @@ static int icc_tag (ICC *state,
   return 0;
 }
 
-static const Babl *babl_trc_from_icc (ICC  *state, int offset,
-                                      const char **error)
+static const Babl *
+babl_trc_from_icc (ICC         *state, 
+                   int          offset,                                      
+                   const char **error)
 {
   {
     int count = icc_read (u32, offset + 8);
@@ -390,7 +457,10 @@ static const Babl *babl_trc_from_icc (ICC  *state, int offset,
   return NULL;
 }
 
-static void icc_allocate_tag (ICC *state, const char *tag, int size)
+static void 
+icc_allocate_tag (ICC        *state, 
+                  const char *tag, 
+                  int         size)
 {
     while (state->no % 4 != 0)
       state->no++;
@@ -403,7 +473,9 @@ static void icc_allocate_tag (ICC *state, const char *tag, int size)
     state->no+=size;
 }
 
-static void icc_duplicate_tag(ICC *state, const char *tag)
+static void 
+icc_duplicate_tag(ICC        *state, 
+                  const char *tag)
 {
     icc_write (sign, 128 + 4 + 4 * state->headpos++, tag);
     icc_write (u32,  128 + 4 + 4 * state->headpos++, state->p);
@@ -414,14 +486,15 @@ static void icc_duplicate_tag(ICC *state, const char *tag)
 static const uint16_t lut_srgb_26[]={0,202,455,864,1423,2154,3060,4156,5454,6960,8689,10637,12821,15247,17920,20855,24042,27501,31233,35247,39549,44132,49018,54208,59695,65535};
 
 
-void write_trc (ICC *state,
-                const char *name,
+void write_trc (ICC           *state,
+                const char    *name,
                 const BablTRC *trc,
-                BablICCFlags flags);
-void write_trc (ICC *state,
-                const char *name,
+                BablICCFlags   flags);
+                
+void write_trc (ICC           *state,
+                const char    *name,
                 const BablTRC *trc,
-                BablICCFlags flags)
+                BablICCFlags   flags)
 {
 switch (trc->type)
 {
@@ -485,9 +558,11 @@ switch (trc->type)
 }
 }
 
-static void symmetry_test (ICC *state);
+static void 
+symmetry_test (ICC *state);
 
-char *babl_space_to_icc (const Babl  *babl,
+char *
+babl_space_to_icc (const Babl  *babl,
                          const char  *description,
                          const char  *copyright,
                          BablICCFlags flags,
@@ -616,7 +691,9 @@ char *babl_space_to_icc (const Babl  *babl,
   }
 }
 
-const char *babl_space_get_icc (const Babl *babl, int *length)
+const char *
+babl_space_get_icc (const Babl *babl, 
+                    int        *length)
 {
   if (!babl->space.icc_profile)
   {
@@ -640,17 +717,19 @@ typedef enum {
   lenientConversion
 } ConversionFlags;
 
-static int ConvertUTF16toUTF8 (const UTF16** sourceStart,
-                               const UTF16* sourceEnd,
-                               UTF8** targetStart,
-                               UTF8* targetEnd,
-                               ConversionFlags flags);
+static int 
+ConvertUTF16toUTF8 (const UTF16   **sourceStart,
+                    const UTF16    *sourceEnd,
+                    UTF8          **targetStart,
+                    UTF8           *targetEnd,
+                    ConversionFlags flags);
 
-static char *icc_decode_mluc (ICC        *state,
-                              int         offset,
-                              int         element_length,
-                              const char *lang,
-                              const char *country)
+static char *
+icc_decode_mluc (ICC        *state,
+                 int         offset,
+                 int         element_length,
+                 const char *lang,
+                 const char *country)
 {
   int n_records   = icc_read (u32, offset + 8);
   int record_size = icc_read (u32, offset + 12);
@@ -698,7 +777,11 @@ static char *icc_decode_mluc (ICC        *state,
   return NULL;
 }
 
-static char *decode_string (ICC *state, const char *tag, const char *lang, const char *country)
+static char *
+decode_string (ICC        *state, 
+               const char *tag, 
+               const char *lang, 
+               const char *country)
 {
   int offset, element_size;
 
@@ -1032,11 +1115,12 @@ static void symmetry_test (ICC *state)
   assert (icc_read (u32, 8) == 4);
 }
 
-char *babl_icc_get_key (const char *icc_data,
-                        int         icc_length,
-                        const char *key,
-                        const char *language,
-                        const char *country)
+char *
+babl_icc_get_key (const char *icc_data,
+                  int         icc_length,
+                  const char *key,
+                  const char *language,
+                  const char *country)
 {
   char *ret = NULL;
   ICC *state = icc_state_new ((void*)icc_data, icc_length, 0);
@@ -1140,6 +1224,7 @@ typedef uint32_t        UTF32;  /* at least 32 bits */
 typedef unsigned short  UTF16;  /* at least 16 bits */
 typedef unsigned char   UTF8;   /* typically 8 bits */
 typedef unsigned char   Boolean; /* 0 or 1 */
+
 typedef enum {
   conversionOK,           /* conversion successful */
   sourceExhausted,        /* partial character in source, but hit end */
@@ -1159,8 +1244,12 @@ static const int halfShift  = 10; /* used for shifting by 10 bits */
 static const UTF32 halfBase = 0x0010000UL;
 static const UTF8 firstByteMark[7] = { 0x00, 0x00, 0xC0, 0xE0, 0xF0, 0xF8, 0xFC };
 
-static int ConvertUTF16toUTF8 (const UTF16** sourceStart, const UTF16* sourceEnd,
-	UTF8** targetStart, UTF8* targetEnd, ConversionFlags flags)
+static int 
+ConvertUTF16toUTF8 (const UTF16   **sourceStart, 
+                    const UTF16    *sourceEnd,
+	                 UTF8          **targetStart, 
+	                 UTF8           *targetEnd, 
+	                 ConversionFlags flags)
 {
     ConversionResult result = conversionOK;
     const UTF16* source = *sourceStart;
