@@ -159,6 +159,8 @@ models (void)
     babl_component_from_id (BABL_RED),
     babl_component_from_id (BABL_GREEN),
     babl_component_from_id (BABL_BLUE),
+    "rgb",
+    "linear",
     NULL);
 
   babl_model_new (
@@ -167,6 +169,10 @@ models (void)
     babl_component_from_id (BABL_GREEN_MUL_ALPHA),
     babl_component_from_id (BABL_BLUE_MUL_ALPHA),
     babl_component_from_id (BABL_ALPHA),
+    "rgb",
+    "linear",
+    "premultiplied",
+    "alpha",
     NULL);
 
   babl_model_new (
@@ -174,6 +180,8 @@ models (void)
     babl_component_from_id (BABL_RED_NONLINEAR),
     babl_component_from_id (BABL_GREEN_NONLINEAR),
     babl_component_from_id (BABL_BLUE_NONLINEAR),
+    "rgb",
+    "nonlinear",
     NULL);
 
   babl_model_new (
@@ -181,6 +189,8 @@ models (void)
     babl_component_from_id (BABL_RED_PERCEPTUAL),
     babl_component_from_id (BABL_GREEN_PERCEPTUAL),
     babl_component_from_id (BABL_BLUE_PERCEPTUAL),
+    "rgb",
+    "perceptual",
     NULL);
 
   babl_model_new (
@@ -189,6 +199,9 @@ models (void)
     babl_component_from_id (BABL_GREEN_NONLINEAR),
     babl_component_from_id (BABL_BLUE_NONLINEAR),
     babl_component_from_id (BABL_ALPHA),
+    "rgb",
+    "nonlinear",
+    "alpha",
     NULL);
 
   babl_model_new (
@@ -197,6 +210,9 @@ models (void)
     babl_component_from_id (BABL_GREEN_PERCEPTUAL),
     babl_component_from_id (BABL_BLUE_PERCEPTUAL),
     babl_component_from_id (BABL_ALPHA),
+    "rgb",
+    "perceptual",
+    "alpha",
     NULL);
 
   babl_model_new (
@@ -205,6 +221,10 @@ models (void)
     babl_component_from_id (BABL_GREEN_NONLINEAR_MUL_ALPHA),
     babl_component_from_id (BABL_BLUE_NONLINEAR_MUL_ALPHA),
     babl_component_from_id (BABL_ALPHA),
+    "rgb",
+    "nonlinear",
+    "premultiplied",
+    "alpha",
     NULL);
 
   babl_model_new (
@@ -213,6 +233,10 @@ models (void)
     babl_component_from_id (BABL_GREEN_PERCEPTUAL_MUL_ALPHA),
     babl_component_from_id (BABL_BLUE_PERCEPTUAL_MUL_ALPHA),
     babl_component_from_id (BABL_ALPHA),
+    "rgb",
+    "perceptual",
+    "premultiplied",
+    "alpha",
     NULL);
 }
 
@@ -424,9 +448,9 @@ rgba2rgba_nonlinear_premultiplied (Babl *conversion,
 
 static void
 rgba_nonlinear_premultiplied2rgba (Babl *conversion,
-                                   char           *src,
-                                   char           *dst,
-                                   long            samples)
+                                   char *src,
+                                   char *dst,
+                                   long  samples)
 {
   const Babl *space = babl_conversion_get_source_space (conversion);
   const Babl **trc  = (void*)space->space.trc;
@@ -511,13 +535,13 @@ static const Babl *perceptual_trc = NULL;
 
 static void
 g3_perceptual_from_linear (Babl  *conversion,
-                          int    src_bands,
-                          char **src,
-                          int   *src_pitch,
-                          int    dst_bands,
-                          char **dst,
-                          int   *dst_pitch,
-                          long   samples)
+                          int     src_bands,
+                          char  **src,
+                          int    *src_pitch,
+                          int     dst_bands,
+                          char  **dst,
+                          int    *dst_pitch,
+                          long    samples)
 {
   const Babl *trc  = perceptual_trc;
 
@@ -538,13 +562,13 @@ g3_perceptual_from_linear (Babl  *conversion,
 
 static void
 g3_perceptual_to_linear (Babl  *conversion,
-                        int    src_bands,
-                        char **src,
-                        int   *src_pitch,
-                        int    dst_bands,
-                        char **dst,
-                        int   *dst_pitch,
-                        long   samples)
+                        int     src_bands,
+                        char  **src,
+                        int    *src_pitch,
+                        int     dst_bands,
+                        char  **dst,
+                        int    *dst_pitch,
+                        long    samples)
 {
   const Babl *trc  = perceptual_trc;
   long n = samples;
@@ -570,9 +594,9 @@ g3_perceptual_to_linear (Babl  *conversion,
 
 static void
 rgba2rgba_perceptual_premultiplied (Babl *conversion,
-                                   char *src,
-                                   char *dst,
-                                   long  samples)
+                                    char *src,
+                                    char *dst,
+                                    long  samples)
 {
   const Babl *trc  = perceptual_trc;
   long n = samples;
@@ -635,9 +659,9 @@ rgba_perceptual_premultiplied2rgba (Babl *conversion,
 
 static void
 rgba2rgba_perceptual (Babl *conversion,
-                     char *src,
-                     char *dst,
-                     long  samples)
+                      char *src,
+                      char *dst,
+                      long  samples)
 {
   const Babl *trc   = perceptual_trc;
   long n = samples;
@@ -656,9 +680,9 @@ rgba2rgba_perceptual (Babl *conversion,
 
 static void
 rgba_perceptual2rgba (Babl *conversion,
-                     char *src,
-                     char *dst,
-                     long  samples)
+                      char *src,
+                      char *dst,
+                      long  samples)
 {
   const Babl *trc   = perceptual_trc;
   long n = samples;
@@ -1273,9 +1297,9 @@ rgba2rgba_nonlinear_premultiplied_float (Babl *conversion,
 
 static void
 rgba_nonlinear_premultiplied2rgba_float (Babl *conversion,
-                                         char           *src,
-                                         char           *dst,
-                                         long            samples)
+                                         char *src,
+                                         char *dst,
+                                         long  samples)
 {
   const Babl *space = babl_conversion_get_source_space (conversion);
   const Babl **trc  = (void*)space->space.trc;
@@ -1431,7 +1455,8 @@ g3_perceptual_to_linear_float (Babl  *conversion,
 }
 
 
-static void init_single_precision (void)
+static void 
+init_single_precision (void)
 {
 
   babl_format_new (
