@@ -43,7 +43,8 @@ conv_float_u8_two_table_map (float value)
 }
 
 static void
-conv_rgbafloat_linear_cairo24_le (const Babl *conversion,unsigned char *src_char,
+conv_rgbafloat_linear_cairo24_le (const Babl    *conversion,
+                                  unsigned char *src_char,
                                   unsigned char *dst,
                                   long           samples)
 {
@@ -61,7 +62,8 @@ conv_rgbafloat_linear_cairo24_le (const Babl *conversion,unsigned char *src_char
 }
 
 static void
-conv_rgbfloat_linear_cairo24_le (const Babl *conversion,unsigned char *src_char,
+conv_rgbfloat_linear_cairo24_le (const Babl    *conversion,
+                                 unsigned char *src_char,
                                  unsigned char *dst,
                                  long           samples)
 {
@@ -80,7 +82,8 @@ conv_rgbfloat_linear_cairo24_le (const Babl *conversion,unsigned char *src_char,
 }
 
 static void
-conv_rgbafloat_linear_rgbu8_gamma (const Babl *conversion,unsigned char *src_char,
+conv_rgbafloat_linear_rgbu8_gamma (const Babl    *conversion,
+                                   unsigned char *src_char,
                                    unsigned char *dst,
                                    long           samples)
 {
@@ -108,7 +111,8 @@ conv_rgbafloat_linear_rgbu8_gamma (const Babl *conversion,unsigned char *src_cha
 
 
 static void
-conv_rgbafloat_linear_rgbau8_gamma (const Babl *conversion,unsigned char *src_char,
+conv_rgbafloat_linear_rgbau8_gamma (const Babl    *conversion,
+                                    unsigned char *src_char,
                                     unsigned char *dst,
                                     long           samples)
 {
@@ -127,7 +131,8 @@ conv_rgbafloat_linear_rgbau8_gamma (const Babl *conversion,unsigned char *src_ch
 }
 
 static void
-conv_rgbfloat_linear_rgbu8_gamma (const Babl *conversion,unsigned char *src_char,
+conv_rgbfloat_linear_rgbu8_gamma (const Babl    *conversion,
+                                  unsigned char *src_char,
                                   unsigned char *dst,
                                   long           samples)
 {
@@ -146,7 +151,8 @@ conv_rgbfloat_linear_rgbu8_gamma (const Babl *conversion,unsigned char *src_char
 }
 
 static void
-conv_yfloat_linear_yu8_gamma (const Babl *conversion,unsigned char *src_char,
+conv_yfloat_linear_yu8_gamma (const Babl    *conversion,
+                              unsigned char *src_char,
                               unsigned char *dst,
                               long           samples)
 {
@@ -160,7 +166,8 @@ conv_yfloat_linear_yu8_gamma (const Babl *conversion,unsigned char *src_char,
 }
 
 static void
-conv_yafloat_linear_yau8_gamma (const Babl *conversion,unsigned char *src_char,
+conv_yafloat_linear_yau8_gamma (const Babl    *conversion,
+                                unsigned char *src_char,
                                 unsigned char *dst,
                                 long           samples)
 {
